==> haskell-test-framework-hunit-0.3.0.2-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-hunit
version: 0.3.0.2
id: test-framework-hunit-0.3.0.2-J53EDIV0LW1BlONtUz2ASV
key: test-framework-hunit-0.3.0.2-J53EDIV0LW1BlONtUz2ASV
license: BSD3
maintainer: Haskell Libraries <libraries@haskell.org>
homepage: https://batterseapower.github.io/test-framework/
synopsis: HUnit support for the test-framework package.
description:
    HUnit support for the test-framework package.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
indefinite: False
exposed-modules:
    Test.Framework.Providers.HUnit
abi: 9f769357e09cde647cbc6434358989ea
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/test-framework-hunit-0.3.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/test-framework-hunit-0.3.0.2
hs-libraries: HStest-framework-hunit-0.3.0.2-J53EDIV0LW1BlONtUz2ASV
depends:
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4 base-4.10.1.0
    extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF
    test-framework-0.8.1.1-1j2D7D7TsB6Dk6k7Kv9vsS
abi-depends: HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=cc02d4bbc4678b779cddf8743bb71eea
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF=ff98b9e1ba3a1bc553e70d357f632c01
             test-framework-0.8.1.1-1j2D7D7TsB6Dk6k7Kv9vsS=61185a2abaab3538c468e070b14b2d69
haddock-interfaces: /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock
haddock-html: /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-hunit-0.3.0.2-22-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-hunit
version: 0.3.0.2
id: test-framework-hunit-0.3.0.2-4UPbk8LiaKJGYRYcc2hrnl
key: test-framework-hunit-0.3.0.2-4UPbk8LiaKJGYRYcc2hrnl
license: BSD3
maintainer: Haskell Libraries <libraries@haskell.org>
homepage: https://batterseapower.github.io/test-framework/
synopsis: HUnit support for the test-framework package.
description:
    HUnit support for the test-framework package.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
indefinite: False
exposed-modules:
    Test.Framework.Providers.HUnit
abi: 0cb0a18dd54f489631bf34e781ace196
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/test-framework-hunit-0.3.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/test-framework-hunit-0.3.0.2
hs-libraries: HStest-framework-hunit-0.3.0.2-4UPbk8LiaKJGYRYcc2hrnl
depends:
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4 base-4.10.1.0
    extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF
    test-framework-0.8.2.0-RpsbodDzl7J2ZtjD7J1P9
abi-depends: HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=cc02d4bbc4678b779cddf8743bb71eea
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF=ff98b9e1ba3a1bc553e70d357f632c01
             test-framework-0.8.2.0-RpsbodDzl7J2ZtjD7J1P9=99e1c1d4e6243476316e4646ce3c94b7
haddock-interfaces: /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock
haddock-html: /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
